#
# spec file for package doom64ex-plus
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           doom64ex-plus
Summary:        An improved modern version of Doom64EX
Version:        4.0.0.3
Release:        3.1
Group:          Amusements/Games/3D/Shoot
License:        GPL-2.0-or-later
URL:            https://github.com/atsb/Doom64EX-Plus
Source0:        %{name}-%{version}.tar.gz
Patch0:         fix-user-dir.patch
# PATCH-FIX-UPSTREAM fix-save-bug.patch -- from PR 310
Patch1:         fix-save-bug.patch
BuildRequires:  gcc
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl3) >= 3.1.3
BuildRequires:  pkgconfig(zlib)
Requires(post): hicolor-icon-theme
Requires(postun): hicolor-icon-theme

%define           datafilesdir  %{_datadir}/games/%{name}
%define           gameexefile DOOM64EX-Plus

%description
Doom 64 EX+ is a continuation project of Samuel "Kaiser" Villarreal's
Doom 64 EX aimed to recreate DOOM 64 as closely as possible with
additional modding features.

Doom64EX is a reverse-engineering project aimed to recreate
Doom64 as close as possible with additional modding features.

You must place file DOOM64.WAD (case-sensitive) from the Steam or GOG version
of Doom 64 into either folder %datafilesdir or ~/.local/share/doom64ex-plus

%prep
%setup -q -n Doom64EX-Plus-%{version}.SDL.3.1.3
%patch -P 0 -p 1
%patch -P 1 -p 1
sed -i 's/__DATE__/"unset"/' src/engine/i_main.c

%build
export CFLAGS="-Wno-pointer-sign -Wno-incompatible-pointer-types %{optflags} -DDOOM_UNIX_INSTALL -DDOOM_UNIX_SYSTEM_DATADIR=\\\"%{datafilesdir}\\\""
%make_build

%install
install -D -t "%{buildroot}%{_bindir}" %{gameexefile}
install -Dm 644 -t "%{buildroot}%{datafilesdir}" %{name}.wad doomsnd.sf2
install -Dm 644 src/engine/%{name}.png "%{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png"

mkdir "%{buildroot}%{_datadir}/applications"
cat > "%{buildroot}%{_datadir}/applications/%{name}.desktop" <<EOF
[Desktop Entry]
Name=Doom 64 EX+
Exec=%{gameexefile}
Icon=doom64ex-plus
Type=Application
Comment=A Doom64 game engine
Categories=Game;ActionGame;
EOF

%suse_update_desktop_file %{name}

%post
if [ $1 -eq 1 ]; then
    # shown on installs only
    echo "INFO: %name: The global IWAD directory is %{datafilesdir}"
    echo "You must place file DOOM.WAD (case-sensitive) from the Steam or GOG version
    	 of Doom64 into that folder or in ~/.local/share/doom64ex-plus"
fi

%files
%doc AUTHORS README.md
%license COPYING
%{_bindir}/%{gameexefile}
%{datafilesdir}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png

%changelog
* Tue Jun 17 2025 Michael Pujos <pujos.michael@gmail.com>
- added fix-save-bug.patch -- from PR 310
- fix compilation with gcc 15
* Mon Oct  7 2024 Carsten Ziepke <kieltux@gmail.com>
- Fix building for Leap >= 15.6, add number to patch
* Sun Oct  6 2024 Michael Pujos <pujos.michael@gmail.com>
- added fix-user-dir.patch
- New version 4.0.0.3:
  * uses the stable API for SDL 3.1.3
  * fix compilation failure with GCC
  * fix totalsecret bug
- New version 4.0.0.2:
  * Fix s_driver cvar
  * Change "SDL_SetRelativeMouseMode" to "SDL_SetWindowRelativeMouseMode"
  * Added IWAD auto-detection
* Fri Aug  2 2024 Michael Pujos <pujos.michael@gmail.com>
- removed system-datadir.patch
- New version 4.0.0.1:
  * Fix wrong predefined macro used for specific Linux code for data dir
  * Improve data dir handling on Linux and OpenBSD
  * Minor README changes
  * Fix segfault on crushing
  * Fix array over run which can cause Zone corruption
  * Fix MAP08 thing trigger bug that was stopping some code being executed,
    inc secret total bug during game and level stats at the end of levels
  * Fix crusher speed to make it the same speed as remaster
* Tue May  7 2024 Michael Pujos <pujos.michael@gmail.com>
- fixed failure for game to find its data files in /usr/share/games/doom64ex-plus
- removed disable-arm-asm.patch
- removed custom Makefile
- New version 4.0.0.0:
  * Migration to SDL3 with zero SDL2 fallback option, SDL2 is entirely
    deprecated and the only rendering path, is the current SDL3 preview's
  * High resolution scaled image support (similar to remaster).
    So MDOOM's, chapter interpics, LEGAL text etc.. can all be used with
    high resolution images. Only exception is the 'EVIL' interpic which
    remains scaled the same as remaster. See the EX+ wad for example dimensions
    for width x height and try not to deviate from them too much
  * Optimisations for frame timing. EX+ should now be absolutely buttery
    smooth at all times, with zero 'jitteriness'.
    Tested on an ARC A580 and no issues
  * 32bit support is deprecated entirely
  * Bunch of other stuff here and there :D
* Sun Jan 14 2024 Michael Pujos <pujos.michael@gmail.com>
- better Makefile
- remove a few unnecessary dependencies
- added disable-arm-asm.patch to fix ARM compilation
* Tue Dec 26 2023 Michael Pujos <pujos.michael@gmail.com>
- Initial version
